Class: ClerkHttpClient::CreateSAMLConnectionRequest
- Inherits:
-
Object
- Object
- ClerkHttpClient::CreateSAMLConnectionRequest
- Defined in:
- lib/clerk-http-client/models/create_saml_connection_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attribute_mapping ⇒ Object
Returns the value of attribute attribute_mapping.
-
#domain ⇒ Object
The domain of your organization.
-
#idp_certificate ⇒ Object
The X.509 certificate as provided by the IdP.
-
#idp_entity_id ⇒ Object
The Entity ID as provided by the IdP.
-
#idp_metadata ⇒ Object
The XML content of the IdP metadata file.
-
#idp_metadata_url ⇒ Object
The URL which serves the IdP metadata.
-
#idp_sso_url ⇒ Object
The Single-Sign On URL as provided by the IdP.
-
#name ⇒ Object
The name to use as a label for this SAML Connection.
-
#provider ⇒ Object
The IdP provider of the connection.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSAMLConnectionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSAMLConnectionRequest
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ClerkHttpClient::CreateSAMLConnectionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ClerkHttpClient::CreateSAMLConnectionRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'domain') self.domain = attributes[:'domain'] else self.domain = nil end if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'idp_entity_id') self.idp_entity_id = attributes[:'idp_entity_id'] end if attributes.key?(:'idp_sso_url') self.idp_sso_url = attributes[:'idp_sso_url'] end if attributes.key?(:'idp_certificate') self.idp_certificate = attributes[:'idp_certificate'] end if attributes.key?(:'idp_metadata_url') self. = attributes[:'idp_metadata_url'] end if attributes.key?(:'idp_metadata') self. = attributes[:'idp_metadata'] end if attributes.key?(:'attribute_mapping') self.attribute_mapping = attributes[:'attribute_mapping'] end end |
Instance Attribute Details
#attribute_mapping ⇒ Object
Returns the value of attribute attribute_mapping.
42 43 44 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 42 def attribute_mapping @attribute_mapping end |
#domain ⇒ Object
The domain of your organization. Sign in flows using an email with this domain, will use this SAML Connection.
22 23 24 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 22 def domain @domain end |
#idp_certificate ⇒ Object
The X.509 certificate as provided by the IdP
34 35 36 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 34 def idp_certificate @idp_certificate end |
#idp_entity_id ⇒ Object
The Entity ID as provided by the IdP
28 29 30 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 28 def idp_entity_id @idp_entity_id end |
#idp_metadata ⇒ Object
The XML content of the IdP metadata file. If present, it takes priority over the corresponding individual properties
40 41 42 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 40 def @idp_metadata end |
#idp_metadata_url ⇒ Object
The URL which serves the IdP metadata. If present, it takes priority over the corresponding individual properties
37 38 39 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 37 def @idp_metadata_url end |
#idp_sso_url ⇒ Object
The Single-Sign On URL as provided by the IdP
31 32 33 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 31 def idp_sso_url @idp_sso_url end |
#name ⇒ Object
The name to use as a label for this SAML Connection
19 20 21 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 19 def name @name end |
#provider ⇒ Object
The IdP provider of the connection.
25 26 27 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 25 def provider @provider end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 268 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = ClerkHttpClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 82 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 67 def self.attribute_map { :'name' => :'name', :'domain' => :'domain', :'provider' => :'provider', :'idp_entity_id' => :'idp_entity_id', :'idp_sso_url' => :'idp_sso_url', :'idp_certificate' => :'idp_certificate', :'idp_metadata_url' => :'idp_metadata_url', :'idp_metadata' => :'idp_metadata', :'attribute_mapping' => :'attribute_mapping' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 244 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 106 107 108 109 110 111 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 102 def self.openapi_nullable Set.new([ :'idp_entity_id', :'idp_sso_url', :'idp_certificate', :'idp_metadata_url', :'idp_metadata', :'attribute_mapping' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 87 def self.openapi_types { :'name' => :'String', :'domain' => :'String', :'provider' => :'String', :'idp_entity_id' => :'String', :'idp_sso_url' => :'String', :'idp_certificate' => :'String', :'idp_metadata_url' => :'String', :'idp_metadata' => :'String', :'attribute_mapping' => :'CreateSAMLConnectionRequestAttributeMapping' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 215 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && domain == o.domain && provider == o.provider && idp_entity_id == o.idp_entity_id && idp_sso_url == o.idp_sso_url && idp_certificate == o.idp_certificate && == o. && == o. && attribute_mapping == o.attribute_mapping end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 339 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
231 232 233 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 231 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
237 238 239 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 237 def hash [name, domain, provider, idp_entity_id, idp_sso_url, idp_certificate, , , attribute_mapping].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @domain.nil? invalid_properties.push('invalid value for "domain", domain cannot be nil.') end if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
315 316 317 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 315 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 321 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
309 310 311 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 309 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 |
# File 'lib/clerk-http-client/models/create_saml_connection_request.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @domain.nil? return false if @provider.nil? provider_validator = EnumAttributeValidator.new('String', ["saml_custom", "saml_okta", "saml_google", "saml_microsoft"]) return false unless provider_validator.valid?(@provider) true end |